*************
API Reference
*************

The Panel API Reference Manual provides a comprehensive reference for
all methods and parameters on Panel components. For more information
on how to use the components see the `Reference Gallery
<../reference>`_.

Module Structure
________________

Panel subpackages
-----------------

`io`_
 Utilities for working with Panel components
`layout`_
 Panel layout components
`pane`_
 Panel layout components
`param`_
 Components for integration with the param library
`pipeline`_
 Panel Pipeline component
`widgets`_
 Widget components
`viewable`_
 Baseclasses for all Panel components

.. toctree::
   :maxdepth: 2
   :hidden:

   io <panel.io>
   layout <panel.layout>
   pane <panel.pane>
   param <panel.param>
   pipeline <panel.pipeline>
   template <panel.template>
   widgets <panel.widgets>
   viewable <panel.viewable>
   util <panel.util>

.. _io: panel.io.html
.. _layout: panel.layout.html
.. _pane: panel.pane.html
.. _param: panel.param.html
.. _pipeline: panel.pipeline.html
.. _template: panel.template.html
.. _widgets: panel.widgets.html
.. _viewable: panel.viewable.html
